local ent = {}

function ent:create( x, y )
	self.x = x
	self.y = y
	self.w = 20
	self.h = 32
	self.oX = 0
	self.oY = 0
	self.sX = 1
	self.sY = 1
	self.vX = 0
	self.vY = 0
	self.x_speed = 256
	self.y_speed = 256
	self.time = 0
	self.health = 20
	self.move = 'right'
	
	self.controlled = false
	self.ai = true
	self.moving = false
	self.falling = true
	self.jumping = false
	self.can_jump = false
	self.facing_right = true
	self.facing_left = false
	self.collides_ground = true
	
	self.quad = love.graphics.newImage( 'textures/enemies/cat.png' )
	self.tile_w, self.tile_h = 64, 64
	self.quad_w, self.quad_h = self.quad:getWidth(), self.quad:getHeight()
	self.quad_info = {
	--wagging/standing
		{ 0, 0 }, 
		{ 0, 64 },
		{ 64, 64 }, 
		{ 128, 64 }, 
	--walking
		{ 64, 0 }, 
		{ 128, 0 }, 
		{ 192, 0 }, 
		{ 256, 0 }, 
	}
	self.quads = {}
	for i = 1, #self.quad_info do
		self.quads[i] = love.graphics.newQuad( self.quad_info[i][1], self.quad_info[i][2], self.tile_w, self.tile_h, self.quad_w, self.quad_h, self.oX, self.oY )
	end
	self.anim_timer = 0
	self.pnum = 1
end

function ent:draw()
	self.quad:setFilter( 'nearest', 'nearest' )
	self.tile_table = { { self.pnum } }
	for i = 1, #self.tile_table do
		local row = self.tile_table[i]
		for ii = 1, #self.tile_table[i] do
			local number = row[ii]
			love.graphics.drawq( self.quad, self.quads[number], self.x, self.y, self.r, self.sX, self.sY, self.oX, self.oY )
		end
	end
end

function ent:right()
	self.moving = true
	
	self.sX = 1
	self.oX = 0
	self.vX = self.x_speed
	self.facing_right = true
	self.facing_left = false
end

function ent:left()
	self.moving = true
	
	self.sX = -1
	self.oX = 64
	self.vX = -1 * self.x_speed
	self.facing_right = false
	self.facing_left = true
end

function ent:up()
	if self.can_jump then
		self.vY = -1 * self.y_speed
		self.jumping = true
		self.can_jump = false
		self.falling = false
	end
end

function ent:down()
	self.vY = self.y_speed
	self.can_jump = false
end

function ent:stop()
	self.vX = 0
	self.moving = false
	self.pnum = 1
end

function ent:hit_ground( cur_y )
	self.vY = 0
	self.y = cur_y * 32 - self.tile_h
	self.jumping = false
	self.can_jump = true
	self.falling = false
end

function ent:hit_wall( cur_x, dir )
	self.vX = 0
	if dir == 'left' then
		self.x = cur_x * 32 - 42
	elseif dir == 'right' then
		self.x = cur_x * 32 - 52
	end
	if self.move == 'right' then 
		self.move = 'left' 
	elseif self.move == 'left' then
		self.move = 'right'
	end
end

function ent:update(dt)
	local dt = love.timer.getDelta()
	self.anim_timer = self.anim_timer + dt
	
	if self.moving and not self.jumping then
		if self.anim_timer > .1 then
			self.pnum = self.pnum + 1
			self.anim_timer = 0
		end
		if self.pnum > 8 then
			self.pnum = 5
		end
	elseif not self.moving and not self.jumping then
		if self.anim_timer > .1 then
			self.pnum = self.pnum + 1
			self.anim_timer = 0
		end
		if self.pnum > 4 then
			self.pnum = 1
		end
	end
	
	if self.falling then
		ent:down()
	end
	
	if self.move == 'right' then
		self:right()
	elseif self.move == 'left' then
		self:left()
	end
	
	self.x = self.x + self.vX * dt
	self.y = self.y + self.vY * dt
end

return ent

--make final cat bosses nyan cat and keyboard cat!