local ent = {}

function ent:create( x, y )
	self.x, self.y = x, y
	self.vX = 0
	self.vY = 0
	self.x_speed = 256 
	self.y_speed = 256 
	self.r = 0 
	self.sX = 1
	self.sY = 1
	self.oX = 0
	self.oY = 0
	self.jh = 128 --max jump height
	self.jY = self.y --y where the player jumped
	self.weapon = 'shuriken'
	self.fire_delay = .5
	self.time = 0
	self.ammo = 12
	self.w = 44
	self.h = 32
	self.health = 20

	self.controlled = true
	self.ai = false
	self.jumping = false
	self.can_jump = false
	self.falling = true
	self.moving = false
	self.can_fire = true
	self.collides_ground = true
	self.facing_right = true
	self.facing_left = false
	
	self.quad = love.graphics.newImage( 'textures/player.png' )
	self.tile_w, self.tile_h = 64, 64
	self.quad_w, self.quad_h = self.quad:getWidth(), self.quad:getHeight()
	self.quad_info = {
	--wagging/standing
		{ 0, 0 },   
		{ 0, 64 }, 
		{ 64, 64 }, 
	--walking
		{ 64, 0 },  
		{ 128, 0 },  
		{ 192, 0 },  
		{ 256, 0 }, 
	}
	self.quads = {}
	for i = 1, #self.quad_info do
		self.quads[i] = love.graphics.newQuad( self.quad_info[i][1], self.quad_info[i][2], self.tile_w, self.tile_h, self.quad_w, self.quad_h, self.oX, self.oY )
	end
	self.anim_timer = 0
	self.pnum = 1
end

function ent:draw()
	self.quad:setFilter( 'nearest', 'nearest' )
	self.tile_table = { { self.pnum } }
	for i = 1, #self.tile_table do
		local row = self.tile_table[i]
		for ii = 1, #self.tile_table[i] do
			local number = row[ii]
			love.graphics.drawq( self.quad, self.quads[number], self.x, self.y, self.r, self.sX, self.sY, self.oX, self.oY )
		end
	end
end

function ent:right()
	self.moving = true
	
	self.sX = 1
	self.oX = 0
	self.vX = self.x_speed
	self.facing_right = true
	self.facing_left = false
end

function ent:left()
	self.moving = true
	
	self.sX = -1
	self.oX = 64
	self.vX = -1 * self.x_speed
	self.facing_right = false
	self.facing_left = true
end

function ent:up()
	if self.can_jump then
		self.vY = -1 * self.y_speed
		self.jY = self.y - self.jh
		self.jumping = true
		self.can_jump = false
		self.falling = false
	end
end

function ent:down()
	self.vY = self.y_speed
	self.can_jump = false
end

function ent:stop()
	self.vX = 0
	self.moving = false
	self.pnum = 1
end

function ent:hit_ground( cur_y )
	self.vY = 0
	self.y = cur_y * 32 - self.tile_h
	self.jumping = false
	self.can_jump = true
	self.falling = false
end

function ent:hit_wall( cur_x, dir )
	self.vX = 0
	if dir == 'left' then
		self.x = cur_x * 32 - 42
	elseif dir == 'right' then
		self.x = cur_x * 32 - 52
	end
end

function ent:attack()
	if self.can_fire then
		if self.ammo > 0 then
			self.ammo = self.ammo - 1
			Entities.create( self.weapon, self.x + self.tile_w * self.sX + self.oX, self.y + self.tile_h / 2 + 10, self.sX )
		end
		self.can_fire = false
	end
end

function ent:update(dt)
	local dt = love.timer.getDelta()
	self.anim_timer = self.anim_timer + dt
	
	if self.moving and not self.jumping then
		if self.anim_timer > .1 then
			self.pnum = self.pnum + 1
			self.anim_timer = 0
		end
		if self.pnum > 7 then
			self.pnum = 4
		end
	elseif not self.moving and not self.jumping then
		if self.anim_timer > .1 then
			self.pnum = self.pnum + 1
			self.anim_timer = 0
		end
		if self.pnum > 3 then
			self.pnum = 1
		end
	end
	
	if not self.can_fire then
		self.time = self.time + dt
		if self.time >= self.fire_delay then
			self.can_fire = true
			self.time = 0
		end
	end
	
	if self.jumping then
		if self.y < self.jY then self.falling = true end
	end
	
	if self.falling then
		ent:down()
	end
	
	self.x = self.x + self.vX * dt
	self.y = self.y + self.vY * dt
	
	camera:setPosition( self.x - (love.graphics.getWidth()/2), self.y - (love.graphics.getHeight()/2) )
end

return ent