Tiles = {}
Tiles.layers = {}

function Tiles.startup()
	Tiles.quad = love.graphics.newImage( 'textures/tiles.png' )
	Tiles.tile_w, Tiles.tile_h = 32, 32
	Tiles.quad_w, Tiles.quad_h = Tiles.quad:getWidth(), Tiles.quad:getHeight()
	Tiles.quad_info = {
	--blank	
		{ 192, 32 }, --blank
	--ground
		{ 0, 0 },    --dirt
		{ 32, 0 },   --dirt with grass
		{ 0, 32 },   --gravel
	--sky
		{ 32, 32 },  --stars
	}
	Tiles.quads = {}
	for i = 1, #Tiles.quad_info do
		Tiles.quads[i] = love.graphics.newQuad( Tiles.quad_info[i][1], Tiles.quad_info[i][2], Tiles.tile_w, Tiles.tile_h, Tiles.quad_w, Tiles.quad_h )
	end
end

function Tiles.create( name, tileset )
	local t = {}
	
	table.insert( Tiles.layers, tileset )
	return t
end

function Tiles:draw()
	Tiles.quad:setFilter( 'nearest', 'nearest' )
	for i = 1, #Tiles.layers do
		for ii = 1, #Tiles.layers[i] do
			for iii = 1, #Tiles.layers[i][ii] do
				love.graphics.drawq( Tiles.quad, Tiles.quads[Tiles.layers[i][ii][iii]], ( 32 * iii ) - 32, ( 32 * ii ) - 32 )
			end
		end
	end
end

function Tiles:collide( ent, Tile )
	--get the x and y that corresponds to the tiles
	local x = ent.x + ent.tile_w 
	local y = ent.y + ent.tile_h 
	cur_x = math.floor( x / 32 )
	cur_y = math.floor( y / 32 )
	--make sure that they're there	
	if Tile[cur_y - 1][cur_x] == nil then Tile[cur_y - 1][cur_x] = 2 end
	if Tile[cur_y + 1][cur_x] == nil then Tile[cur_y + 1][cur_x] = 2 end
	if Tile[cur_y][cur_x - 1] == nil then Tile[cur_y][cur_x - 1] = 2 end
	if Tile[cur_y][cur_x + 1] == nil then Tile[cur_y][cur_x + 1] = 2 end
	--define in Laymen's terms
	local up = Tile[cur_y - 1][cur_x]
	local down = Tile[cur_y + 1][cur_x]
	local left =  Tile[cur_y][cur_x - 1]
	local right = Tile[cur_y][cur_x + 1]
	--now collide
	if up ~= 1 and ent.jumping then
		ent:down()
	end
	if down ~= 1 then
		if ent.falling then
			ent:hit_ground( cur_y )
			ent.falling = true
		end
	end
	if left ~= 1 and ent.facing_left and not ent.jumping then
		ent:hit_wall( cur_x, 'left' )
	end
	if right ~= 1 and ent.facing_right and not ent.jumping then
		ent:hit_wall( cur_x, 'right' )
	end
end